@@ -33,8 +33,7 @@
    :paths (comp vec distinct concat)
    :extra-paths (comp vec distinct concat)
    :jvm-opts (comp vec concat)
-   :main-opts (comp last #(remove nil? %) vector)
-   :verbose #(or %1 %2)})
+   :main-opts (comp last #(remove nil? %) vector)})
 
 (defn- choose-rule [alias-key]
   (or (merge-alias-rules alias-key)
@@ -182,23 +181,23 @@
                             :else (get default-deps lib))
             coord-id (ext/dep-id lib use-coord config)
             entry (cond-> {:path parents, :lib lib, :coord coord, :use-coord use-coord, :coord-id coord-id}
-                    override-coord (assoc :override-coord override-coord))]
-        (let [{:keys [include reason]} (include-coord? version-map lib parents exclusions)]
-          (if include
-            (let [use-path (conj parents lib)
-                  {:deps/keys [manifest root] :as manifest-info} (ext/manifest-type lib use-coord config)
-                  use-coord (merge use-coord manifest-info)
-                  children (dir/with-dir (if root (jio/file root) dir/*the-dir*)
-                             (canonicalize-deps (ext/coord-deps lib use-coord manifest config) config))
-                  child-paths (map #(conj use-path %) children)
-                  {:keys [include reason vmap]} (add-coord version-map lib coord-id use-coord parents reason config)]
-              (if include
-                (let [excl' (if-let [excl (:exclusions use-coord)]
-                              (add-exclusion exclusions use-path excl)
-                              exclusions)]
-                  (recur (into q' child-paths) vmap excl' (trace+ trace? trace entry include reason)))
-                (recur q' vmap exclusions (trace+ trace? trace entry include reason))))
-            (recur q' version-map exclusions (trace+ trace? trace entry include reason)))))
+                    override-coord (assoc :override-coord override-coord))
+            {:keys [include reason]} (include-coord? version-map lib parents exclusions)]
+        (if include
+          (let [use-path (conj parents lib)
+                {:deps/keys [manifest root] :as manifest-info} (ext/manifest-type lib use-coord config)
+                use-coord (merge use-coord manifest-info)
+                children (dir/with-dir (if root (jio/file root) dir/*the-dir*)
+                           (canonicalize-deps (ext/coord-deps lib use-coord manifest config) config))
+                child-paths (map #(conj use-path %) children)
+                {:keys [include reason vmap]} (add-coord version-map lib coord-id use-coord parents reason config)]
+            (if include
+              (let [excl' (if-let [excl (:exclusions use-coord)]
+                            (add-exclusion exclusions use-path excl)
+                            exclusions)]
+                (recur (into q' child-paths) vmap excl' (trace+ trace? trace entry include reason)))
+              (recur q' vmap exclusions (trace+ trace? trace entry include reason))))
+          (recur q' version-map exclusions (trace+ trace? trace entry include reason))))
       (cond-> version-map trace? (with-meta {:trace {:log trace, :vmap version-map, :exclusions exclusions}})))))
 
 (defn- lib-paths
@@ -231,11 +230,11 @@
     (resolve-deps deps-map args-map nil))
   ([deps-map args-map settings]
    (let [{:keys [extra-deps default-deps override-deps]} args-map
-         deps (merge (:deps deps-map) extra-deps)]
-     (let [version-map (-> deps
-                         (canonicalize-deps deps-map)
-                         (expand-deps default-deps override-deps deps-map (:trace settings)))]
-       (with-meta (lib-paths version-map deps-map) (meta version-map))))))
+         deps (merge (:deps deps-map) extra-deps)
+         version-map (-> deps
+                       (canonicalize-deps deps-map)
+                       (expand-deps default-deps override-deps deps-map (:trace settings)))]
+     (with-meta (lib-paths version-map deps-map) (meta version-map)))))
 
 (defn- make-tree
   [lib-map]
@@ -271,12 +270,11 @@
     :extra-paths - extra classpath paths to add to the classpath
     :classpath-overrides - a map of lib to path, where path is used instead of the coord's paths
 
-
   Returns the classpath as a string."
   [lib-map paths {:keys [classpath-overrides extra-paths] :as classpath-args}]
   (let [libs (merge-with (fn [coord path] (assoc coord :paths [path])) lib-map classpath-overrides)
         lib-paths (mapcat :paths (vals libs))]
-    (str/join File/pathSeparator (concat extra-paths paths lib-paths))))
+    (str/join File/pathSeparator (remove str/blank? (concat extra-paths paths lib-paths)))))
 
 (comment
   (require '[clojure.tools.deps.alpha.util.maven :as mvn])
@@ -315,7 +313,7 @@
 
   (clojure.pprint/pprint
     (resolve-deps {:deps {'org.clojure/tools.analyzer.jvm {:mvn/version "0.6.9"}}
-                   :mvn/repos mvn/standard-repos} {:verbose true}))
+                   :mvn/repos mvn/standard-repos} nil))
 
   (clojure.pprint/pprint
     (resolve-deps {:deps {'cheshire {:mvn/version "5.7.0"}}
@@ -344,8 +342,7 @@
     (resolve-deps
       {:deps {'org.clojure/core.memoize {:mvn/version "0.5.8"}}
        :mvn/repos mvn/standard-repos}
-      {:override-deps {'org.clojure/clojure {:mvn/version "1.3.0"}}
-       :verbose true})
+      {:override-deps {'org.clojure/clojure {:mvn/version "1.3.0"}}})
     ["src"] nil)
 
   (make-classpath
@@ -382,7 +379,7 @@
     (resolve-deps
       {:deps {'org.clojure/clojure {:mvn/version "1.8.0"}}
        :mvn/repos mvn/standard-repos}
-      {:verbose true})
+      nil)
     nil
     {'org.clojure/clojure "/Users/alex/code/clojure/target/classes"})
 
@@ -391,7 +388,7 @@
              org.clojure/clojurescript {:mvn/version "1.9.946"}
              reagent {:mvn/version "0.6.0"}}
      :mvn/repos mvn/standard-repos}
-    {:verbose true})
+    nil)
 
   ;; err case
   (resolve-deps {:deps {'bogus {:mvn/version "1.2.3"}}
@@ -416,8 +413,8 @@
         (resolve-deps
           {:deps {'com.google.cloud/google-cloud-monitoring {:mvn/version "1.78.0"}}
            :mvn/repos (merge mvn/standard-repos
-                        {"datomic-cloud" {:url "s3://datomic-releases-1fc2183a/maven/releases"}})}
+                        {"datomic-cloud" {:url "s3://datomic-releases-1fc2183a.s3-us-east-1.amazonaws.com/maven/releases"}})}
           nil))
       nil))
 
-  )
+  )
\ No newline at end of file
