@@ -33,9 +33,6 @@
     ;; maven-resolver-transport-http
     [org.eclipse.aether.transport.http HttpTransporterFactory]
 
-    ;; maven-resolver-transport-wagon
-    [org.eclipse.aether.transport.wagon WagonTransporterFactory WagonProvider]
-
     ;; maven-aether-provider
     [org.apache.maven.repository.internal MavenRepositorySystemUtils]
 
@@ -49,7 +46,8 @@
     [org.apache.maven.settings.building DefaultSettingsBuilderFactory]
 
     ;; plexus-utils
-    [org.codehaus.plexus.util.xml Xpp3Dom]))
+    [org.codehaus.plexus.util.xml Xpp3Dom]
+    ))
 
 (set! *warn-on-reflection* true)
 
@@ -124,7 +122,7 @@
 (defn remote-repos
   [repos]
   (->> repos
-    (remove (fn [[name config]] (nil? config)))
+    (remove (fn [[_name config]] (nil? config)))
     (mapv remote-repo)))
 
 ;; Local repository
@@ -138,15 +136,6 @@
 
 ;; Maven system and session
 
-;; TODO: in the future this could be user-extensible
-(deftype CustomProvider []
-  WagonProvider
-  (lookup [_ role-hint]
-    (if (contains? #{"s3" "s3p"} role-hint)
-      (org.springframework.build.aws.maven.PrivateS3Wagon.)
-      (throw (ex-info (str "Unknown wagon provider: " role-hint) {:role-hint role-hint}))))
-  (release [_ wagon]))
-
 ;; Delay creation, but then cache Maven ServiceLocator instance
 (def the-locator
   (delay
@@ -154,8 +143,7 @@
       (.addService RepositoryConnectorFactory BasicRepositoryConnectorFactory)
       (.addService TransporterFactory FileTransporterFactory)
       (.addService TransporterFactory HttpTransporterFactory)
-      (.addService TransporterFactory WagonTransporterFactory)
-      (.setService WagonProvider CustomProvider))))
+      (.addService TransporterFactory clojure.tools.deps.alpha.util.S3TransporterFactory))))
 
 (defn make-system
   ^RepositorySystem []
@@ -166,8 +154,11 @@
     (transferStarted [_ event]
       (let [event ^TransferEvent event
             resource (.getResource event)
-            name (.getResourceName resource)]
-        (printerrln "Downloading:" name "from" (.getRepositoryUrl resource))))
+            name (.getResourceName resource)
+            url (.getRepositoryUrl resource)
+            urlc (count url)
+            report-url (if (pos? urlc) (subs url 0 (dec urlc)) url)] ;; chop trailing /
+        (printerrln "Downloading:" name "from" report-url)))
     (transferCorrupted [_ event]
       (printerrln "Download corrupted:" (.. ^TransferEvent event getException getMessage)))
     (transferFailed [_ event]
